@@ -39,6 +39,12 @@ class TreeSitterParser:
         elif self.language_name == 'javascript':
             from .languages.javascript import JavascriptTreeSitterParser
             self.language_specific_parser = JavascriptTreeSitterParser(self)
+        elif self.language_name == 'cpp':
+            from .languages.cpp import CppTreeSitterParser
+            self.language_specific_parser = CppTreeSitterParser(self)
+        elif self.language_name == 'rust':
+            from .languages.rust import RustTreeSitterParser
+            self.language_specific_parser = RustTreeSitterParser(self)
 
     def parse(self, file_path: Path, is_dependency: bool = False) -> Dict:
         """Dispatches parsing to the language-specific parser."""
@@ -58,6 +64,13 @@ class GraphBuilder:
         self.parsers = {
             '.py': TreeSitterParser('python'),
             '.js': TreeSitterParser('javascript'), # Added JavaScript parser
+            '.jsx': TreeSitterParser('javascript'),
+            '.mjs': TreeSitterParser('javascript'),
+            '.cjs': TreeSitterParser('javascript'),
+            '.cpp': TreeSitterParser('cpp'),
+            '.h': TreeSitterParser('cpp'),
+            '.hpp': TreeSitterParser('cpp'),
+            '.rs': TreeSitterParser('rust'),
         }
         self.create_schema()
 
@@ -209,18 +222,38 @@ class GraphBuilder:
                     """, context=item["context"], file_path=file_path_str, name=item["name"], line_number=item["line_number"])
 
             # Handle imports and create IMPORTS relationships
-            for imp in file_data['imports']:
-                set_clauses = ["m.alias = $alias"]
-                if 'full_import_name' in imp:
-                    set_clauses.append("m.full_import_name = $full_import_name")
-                set_clause_str = ", ".join(set_clauses)
+            for imp in file_data.get('imports', []):
+                logger.info(f"Processing import: {imp}")
+                lang = file_data.get('lang')
+                if lang == 'javascript':
+                    # New, correct logic for JS
+                    module_name = imp.get('source')
+                    if not module_name: continue
 
-                session.run(f"""
-                    MATCH (f:File {{path: $file_path}})
-                    MERGE (m:Module {{name: $name}})
-                    SET {set_clause_str}
-                    MERGE (f)-[:IMPORTS]->(m)
-                """, file_path=file_path_str, **imp)
+                    # Use a map for relationship properties to handle optional alias
+                    rel_props = {'imported_name': imp.get('name', '*')}
+                    if imp.get('alias'):
+                        rel_props['alias'] = imp.get('alias')
+
+                    session.run("""
+                        MATCH (f:File {path: $file_path})
+                        MERGE (m:Module {name: $module_name})
+                        MERGE (f)-[r:IMPORTS]->(m)
+                        SET r += $props
+                    """, file_path=file_path_str, module_name=module_name, props=rel_props)
+                else:
+                    # Existing logic for Python (and other languages)
+                    set_clauses = ["m.alias = $alias"]
+                    if 'full_import_name' in imp:
+                        set_clauses.append("m.full_import_name = $full_import_name")
+                    set_clause_str = ", ".join(set_clauses)
+
+                    session.run(f"""
+                        MATCH (f:File {{path: $file_path}})
+                        MERGE (m:Module {{name: $name}})
+                        SET {set_clause_str}
+                        MERGE (f)-[:IMPORTS]->(m)
+                    """, file_path=file_path_str, **imp)
 
             # Handle CONTAINS relationship between class to their children like variables
             for func in file_data.get('functions', []):
@@ -522,8 +555,16 @@ class GraphBuilder:
             if job_id:
                 self.job_manager.update_job(job_id, status=JobStatus.COMPLETED, end_time=datetime.now())
         except Exception as e:
-            logger.error(f"Failed to build graph for path {path}: {e}", exc_info=True)
+            error_message=str(e)
+            logger.error(f"Failed to build graph for path {path}: {error_message}", exc_info=True)
             if job_id:
+                '''checking if the repo got deleted '''
+                if "no such file found" in error_message or "deleted" in error_message or "not found" in error_message:
+                    status=JobStatus.CANCELLED
+                    
+                else:
+                    status=JobStatus.FAILED
+
                 self.job_manager.update_job(
                     job_id, status=JobStatus.FAILED, end_time=datetime.now(), errors=[str(e)]
-                )
\ No newline at end of file
+                )
